@@ -13,6 +13,7 @@ class ContactVariables:
         cls.ICONSETPATH = None
         cls.UID = None
         cls.NAME = None
+        cls.PHONE = None
         return cls
 
     @classmethod
@@ -46,5 +47,20 @@ class ContactVariables:
     def UserUpdate(cls):
         cls.endpoint = None
         cls.phone = None
+        cls.callsign = None
+        return cls
+
+    @classmethod
+    def SimpleCoT(cls):
+        cls.callsign = None
+        return cls
+
+    @classmethod
+    def Presence(cls):
+        cls.callsign = None
+        return cls
+
+    @classmethod
+    def Route(cls):
         cls.callsign = None
         return cls
\ No newline at end of file
